import React, { useEffect, useState } from 'react';
import { View, Text, Image, StyleSheet, Alert, ActivityIndicator, Dimensions } from 'react-native'
import style from "../../../../Components/common/CommonStyle";
import { PrimaryButton } from 'react-native-digitcamera/src/common/ThemedComponents';
import Orientation from "../../../react-native-orientation";
import Database from "../../../../Components/common/Database"
import Colors from 'react-native-digitcamera/src/common/Colors';

const step1 = require("../common/Image/step1.png")
const step2 = require("../common/Image/step2.png")
const step3 = require("../common/Image/step3.png")
/*
Import Modal from lib
add shouldHeaderVisible props
*/

/*
    Dimension issue fixed
*/

const getAccurateDimensions = () => {
    return Orientation.getInitialOrientation() === "LANDSCAPE" ? Dimensions.get('screen').height : Dimensions.get('screen').width
}
const SCREEN_WIDTH = getAccurateDimensions()

let realm = Database.getRealm();
var instructionInDb = realm.objects("PIVechicleInstruction");

console.log("^^^instruction data^^^", instructionInDb)

const DATA = [
    {
        instructionAssests: step1,
        instructionTitle: "Open the car bonnet",
        instructionData: "Before we get started, please open up the car bonnet",
        okButtonText: "I have opened the bonet",
    },
    {
        instructionAssests: step2,
        instructionTitle: "Start your vehicle",
        instructionData: "The engine should be ON for taking the odomenter reading & while recording the video.",
        okButtonText: "I have started the vehicle"
    },
    {
        instructionAssests: step3,
        instructionTitle: "Find your chasis number",
        instructionData: "Locate your chassis number, you can refer to the image to find chassis number.",
        okButtonText: "I have found the chasis number"
    }
]
const InstructionsScreen = (props) => {
    const [stepCount, setStepCount] = useState(0)
    const [instructionArr, setInstructionArr] = useState(
        JSON.parse(instructionInDb[0]?.instuction)
    );
    const [data, setData] = useState(DATA)
    const [imageLoaded, setImageLoaded] = useState(false)


    useEffect(() => {

        // if (Orientation.getInitialOrientation() === "PORTRAIT") {
        //     Orientation.lockToLandscape()
        // }



        let item = instructionArr.find(item => item.imageName === "VDO")
        console.log("^^^^ VDO TSurveyInstructions ^^^^", item)

    }, [])

    const handleButtonPress = () => {
        /*
        stepCount refers to the number of steps 
        intialized as 0 for to act as index for 
        intstructions array.
        */
        if (stepCount < 2) {
            /*
            Loads next instructions
            */
            setStepCount(stepCount + 1)
            setImageLoaded(false)
        }
        else {
            /*
            startRecording callback
            */
            // setStepCount(0)
            // mockAlert()
            props.startRecording()
        }
    }

    const mockAlert = () => {
        Alert.alert("Started Recording..")
    }


    return (
        <View style={styles.iSContainer}>
            <View style={styles.iSInstructionsContainer}>
                <View style={styles.iSImageContainer}>

                    {/* Image Container */}
                    <View style={styles.iSImageView}>
                        <Image
                            source={data[stepCount].instructionAssests}
                            // source={{ uri: props.instructionAssests === undefined ? data[stepCount].instructionAssests : props.instructionAssests }}
                            style={styles.iSImage}
                            onLoad={() => setImageLoaded(true)}
                        />

                        {/* This indicator will show until image is fetched & displayed. */}
                        {

                            !imageLoaded &&
                            <ActivityIndicator size="large" color={Colors.digitYellow} style={styles.iSFetchingImageIndicator} />
                        }
                    </View>

                    {/* Instructions Details & Action */}
                    <View style={styles.iSInstructionsView}>

                        {/* Instructions Steps,Title,Detailss */}
                        <View style={styles.iSTitleDetailParent}>
                            <View style={styles.iSStepTitle}>
                                <Text style={[styles.iSCurrentStep, style.muliRegLG]}>
                                    Step {" "}
                                    <Text>
                                        {stepCount + 1}/3
                                    </Text>
                                </Text>
                                <Text style={[style.muliBoldDB, styles.iSTitle]}>
                                    {props.instructionTitle === undefined ? data[stepCount].instructionTitle : props.instructionTitle}
                                </Text>
                            </View>
                            <View style={styles.iSDetailsView}>
                                <Text style={[style.muliRegDB, styles.iSDetails]} numberOfLines={6}>
                                    {props.instructionData === undefined ? data[stepCount].instructionData : props.instructionData}
                                </Text>
                            </View>
                        </View>
                        {/* Action Button */}
                        <View style={styles.iSButtonView}>
                            <PrimaryButton
                                onPress={handleButtonPress}
                            >
                                {props.okButtonText === undefined ? data[stepCount].okButtonText : props.okButtonText}
                            </PrimaryButton>
                        </View>
                    </View>
                </View>
            </View>
        </View >
    )
}

// iS = Instruction Screen
const styles = StyleSheet.create({
    iSContainer: {
        // flex: 1,
        justifyContent: 'flex-end',
        backgroundColor: 'transparent'
    },
    iSInstructionsContainer: {
        padding: 16,
        paddingTop: 8,
        // borderTopLeftRadius: 10,
        // borderTopRightRadius: 10,
        // elevation: 5,
        height: SCREEN_WIDTH * 0.75,
        // backgroundColor: 'white'
    },
    iSImageContainer: {
        flex: 1,
        flexDirection: 'row',
        justifyContent: 'space-between'
    },
    iSImageView: {
        flex: 0.5
    },
    iSImage: {
        height: "100%",
        width: "100%",
        borderRadius: 10
    },
    iSInstructionsView: {
        flex: 0.45
    },
    iSTitleDetailParent: {
        flex: 0.7,

    },
    iSStepTitle: {
        // flex: 0.4,
    },
    iSCurrentStep: {
        fontSize: 16
    },
    iSTitle: {
        fontSize: 24,
        marginTop: 8
    },
    iSDetailsView: {
        marginTop: 8,
        // flex: 0.6
        flexDirection: 'row',
        flexShrink: 1
    },
    iSDetails: {
        fontSize: 16,
        flexShrink: 1,
        // textAlign: 'justify'
    },
    iSButtonView: {
        flex: 0.3,
        justifyContent: 'flex-end'
    },
    iSFetchingImageIndicator: {
        position: 'absolute',
        alignSelf: 'center',
        top: 0,
        bottom: 0
    }
})

export default InstructionsScreen;

