import { View, Text, StyleSheet, FlatList, Image, PermissionsAndroid, Dimensions } from 'react-native'
import React, { useEffect, useState } from 'react'
import {
    RC_BOOK,
    RC_BOOK_HN,
} from "react-native-digitcamera/src/common/Constants";
import { translate } from 'react-native-digitcamera/src/common/localize/i18n';
import Carousel from "react-native-snap-carousel";
import Orientation from "react-native-orientation";
import Header from 'react-native-digitcamera/src/Screens/Header';
import reactotron from "reactotron-react-native";
import { PrimaryButton, DashedButton } from 'react-native-digitcamera/src/common/ThemedComponents';
import Database from "../../../../Components/common/Database";
import { useSelector, useDispatch } from 'react-redux';
const deleteIcon = require("react-native-digitcamera/src/common/Image/deleteIcon.png");
const tick = require("react-native-digitcamera/src/common/Image/tick.png");
const camera = require("react-native-digitcamera/src/common/Image/camera.png");



let realm = Database.getRealm();
var instructionInDb = realm.objects("PIVechicleInstruction");
var VehicleData = realm.objects("PIVechicleData");
const activityId = VehicleData[0]?.activityId;


/*
    Dimension issue fix
    in portrait width = width,height = height
    in landscape width = height, width = hieght

    when components goes landscape, the SCREEN_WIDTH is set to width only
    in this fix width is set to height when in landscape.
*/

const getAccurateDimensions = () =>
    Orientation.getInitialOrientation() === "LANDSCAPE" ?
        Dimensions.get('screen').height
        :
        Dimensions.get('screen').width

var SCREEN_WIDTH = getAccurateDimensions()


const RCBPreviewScreen = ({ navigation, route }) => {
    const { nextStencil } = route.params
    console.log("IMAGE data", nextStencil)
    var RealmData = realm.objects("SelectedLang");
    const [, updateState] = React.useState();
    const forceUpdate = React.useCallback(() => updateState({}), []);
    const [instruction, setInstructionArr] = useState(
        JSON.parse(instructionInDb[0]?.instuction)
    );
    const [RCBData, setRCBData] = useState([])

    const rcbPreviewData = useSelector(state => state.rcbPreviewData.rcbPreviewData)
    console.log("^^^^^^^ REDUX ^^^^^^^^", rcbPreviewData)

    // const rcbPreviewDataOtherPages = rcbPreviewData.filter((item, index) => index > 1)

    const isRCB1Taken = rcbPreviewData.find(item => item.name === "RCB1") !== undefined ? true : false
    const isRCB2Taken = rcbPreviewData.find(item => item.name === "RCB2") !== undefined ? true : false


    const dispatch = useDispatch()

    useEffect(() => {
        Orientation.lockToLandscapeLeft()
        // SCREEN_WIDTH = getAccurateDimensions()

        let item = instruction.filter(item => item.imageName.includes("RCB"))
        setRCBData([...item])
        console.log(item)

    }, [])

    const rcBookData = [
        {
            name: "RCB1",
            image: "https://cdn.godigit.com/digitEdgeAssets/Motor/4W_PI_RCB1_V2.jpg",
            info: "RC FRONT SAMPLE",
        },
        {
            name: "RCB2",
            image: "https://cdn.godigit.com/digitEdgeAssets/Motor/4W_PI_RCB2_V2.jpg",
            info: "RC BACK SAMPLE",
        },
    ];

    const _renderRcBookData = ({ item, index }) => {
        return (
            // Image View
            <View style={styles.imageView}>
                <View
                    style={{
                        flex: 1,
                        justifyContent: "center",
                        borderWidth: 1,
                        borderColor: "#DDDDDD",
                        borderRadius: 8,
                    }}
                >
                    {item.image == undefined ? null : (
                        <Image
                            source={{ uri: item.image }}
                            style={{
                                width: "100%",
                                height: "100%",
                                resizeMode: "contain",
                                alignItems: "center",
                            }}
                        />
                    )}
                    <Text style={[styles.sampleText, { paddingBottom: 20 }]}>
                        {translate(item.info)}
                    </Text>
                </View>
            </View>
        );
    };

    const renderItem = ({ index, item }) => {
        return (
            <DashedButton
                // Title={this.props.route?.params?.photo?.split('/')[this.props.route?.params?.photo?.split('/').length - 1]}
                Title={`${activityId}_RCB`}
                RightImage={deleteIcon}
                leftImage={tick}
                onDeletePress={() => {
                    onDashedAddMoreClick();
                }}
            />
        );
    };



    const RCBFrontButtonClick = () => {
        /*
        navigate to camera
        */
        navigateToCamera_RCB("RCB1")
    }

    const RCBBackButtonClick = () => {
        /*
        navigate to camera
        */
        navigateToCamera_RCB("RCB2")

    };

    const handleProceed = () => {
        navigation.navigate("Camera", {
            runNextStencil: true
        })
    }

    const RCBMorePhotosClicked = () => {
        console.log("Taking More Photos.")
        // navigation.navigate("Camera", {
        //     runMoreRCBPhotos: true,
        // })
    }


    const getCameraAudioPermission = async () => {
        console.log("permissoin block 0");

        if (Platform.OS === "android") {
            await getAndroidCameraAudioPermission();
        }
    }

    const getAndroidCameraAudioPermission = async () => {
        console.log("permissoin block 1");

        const grantedCamera = await PermissionsAndroid.request(
            PermissionsAndroid.PERMISSIONS.CAMERA
        );


        const grantedAudio = await PermissionsAndroid.request(
            PermissionsAndroid.PERMISSIONS.RECORD_AUDIO
        );



        if (
            grantedCamera !== PermissionsAndroid.RESULTS.GRANTED ||
            grantedAudio !== PermissionsAndroid.RESULTS.GRANTED
        )
            Alert.alert(translate("Permission denied"));
    }


    const navigateToCamera_RCB = async (docName) => {
        await getCameraAudioPermission();
        // reactotron.log("Document Name  >>>", instuction[index]?.imageName);
        navigation.navigate("Camera", {
            docName
        });
        console.log("after nav");
        return 0;
    }
    // 

    return (
        <View style={{ flex: 1, backgroundColor: 'white', }}>
            <Header
                onbackPress={() => { }}
                onlanguagechange={() => {
                    forceUpdate();
                }}
            ></Header>
            <View style={{ paddingVertical: 16 }}>
                <View style={{ flexDirection: "row", justifyContent: 'space-between' }}>
                    {/* crausel Image View */}
                    <View style={{ flex: 0.5, paddingBottom: 22 }}>
                        <Carousel
                            data={rcbPreviewData.length === 0 ? rcBookData : rcbPreviewData}
                            renderItem={_renderRcBookData}
                            sliderWidth={SCREEN_WIDTH + 10}
                            itemWidth={SCREEN_WIDTH + 10}
                            autoplay={true}
                            loop={true}
                        />
                    </View>
                    <View style={{ flex: 0.48 }}>
                        {/* <ScrollView> */}

                        {/* </ScrollView> */}
                        <FlatList
                            data={["A"]}
                            renderItem={({ item, index }) => {
                                return (
                                    <View key={"" + index}>
                                        {true ? (
                                            <View style={{ marginLeft: 24, marginRight: 24 }}>
                                                <Text style={styles.rcTitle}>
                                                    {translate("RC Book")}
                                                </Text>
                                                {/* RC front */}
                                                <Text style={styles.rcTypeText}>
                                                    {translate("RC Front Page")}
                                                </Text>
                                                {isRCB1Taken ? (
                                                    <DashedButton
                                                        // Title={this.props.route?.params?.photo?.split('/')[this.props.route?.params?.photo?.split('/').length - 1]}
                                                        Title={`${activityId}_RCB1`}
                                                        RightImage={deleteIcon}
                                                        leftImage={tick}
                                                        onDeletePress={() => {
                                                            dispatch({
                                                                type: "DELETE_RCB_IMAGE_BY_TITLE",
                                                                payload: "RCB1"
                                                            })
                                                            // RCBFrontButtonClick();
                                                        }}
                                                    />
                                                ) : (
                                                    <PrimaryButton
                                                        style={{
                                                            marginBottom: 24,
                                                            marginTop: 5,
                                                            backgroundColor: "white",
                                                            borderColor: "#00000",
                                                            borderWidth: 1,
                                                            borderRadius: 4,
                                                        }}
                                                        onPress={() => {
                                                            RCBFrontButtonClick();
                                                        }}
                                                        icon={({ color, size }) => {
                                                            return (
                                                                <Image
                                                                    source={camera}
                                                                    style={{ width: 30, height: 30 }}
                                                                />
                                                            );
                                                        }}
                                                    >
                                                        {translate("Capture Image")}
                                                    </PrimaryButton>
                                                )}

                                                {/* RC back */}
                                                <Text style={styles.rcTypeText}>
                                                    {translate("RC Back Page")}
                                                </Text>
                                                {isRCB2Taken ? (
                                                    <DashedButton
                                                        // Title={this.props.route?.params?.photo?.split('/')[this.props.route?.params?.photo?.split('/').length - 1]}
                                                        Title={`${activityId}_RCB2`}
                                                        RightImage={deleteIcon}
                                                        leftImage={tick}
                                                        onDeletePress={() => {
                                                            dispatch({
                                                                type: "DELETE_RCB_IMAGE_BY_TITLE",
                                                                payload: "RCB2"
                                                            })
                                                            // RCBBackButtonClick()
                                                        }}
                                                    />
                                                ) : (
                                                    <PrimaryButton
                                                        style={{
                                                            marginBottom: 24,
                                                            marginTop: 5,
                                                            backgroundColor: "white",
                                                            borderColor: "#00000",
                                                            borderWidth: 1,
                                                            borderRadius: 4,
                                                        }}
                                                        onPress={() => {
                                                            RCBBackButtonClick();
                                                        }}
                                                        icon={({ color, size }) => {
                                                            return (
                                                                <Image
                                                                    source={camera}
                                                                    style={{ width: 30, height: 30 }}
                                                                />
                                                            );
                                                        }}
                                                    >
                                                        {translate("Capture Image")}
                                                    </PrimaryButton>
                                                )}

                                                {/* RC back if any other */}
                                                <Text style={styles.rcTypeText}>
                                                    {translate("Other RC Pages (if any)")}
                                                </Text>
                                                <FlatList
                                                    // data={[rcbPreviewDataOtherPages.length === 0 ? [] : rcbPreviewDataOtherPages]}
                                                    data={[]}
                                                    keyExtractor={(item, index) => index.toString()}
                                                    renderItem={renderItem}
                                                    maxToRenderPerBatch={100}
                                                    updateCellsBatchingPeriod={1000}
                                                />
                                                <PrimaryButton
                                                    style={{
                                                        marginTop: 5,
                                                        backgroundColor: "white",
                                                        borderColor: "#00000",
                                                        borderWidth: 1,
                                                        borderRadius: 4,
                                                    }}
                                                    onPress={() => {
                                                        RCBMorePhotosClicked()
                                                        console.log("More photos clicked")
                                                    }}
                                                >
                                                    {translate("+  Add Photos")}
                                                </PrimaryButton>

                                                {/* Button */}
                                                <PrimaryButton
                                                    style={{
                                                        marginBottom: 24,
                                                        marginTop: SCREEN_WIDTH / 8,
                                                    }}
                                                    onPress={() => {
                                                        handleProceed()
                                                    }}
                                                    disabled={!isRCB1Taken && !isRCB2Taken}
                                                >
                                                    Proceed
                                                </PrimaryButton>
                                            </View>
                                        ) : null}
                                    </View>
                                );
                            }}
                            keyExtractor={(item) => (item === undefined ? 1 : item.id)}
                        ></FlatList>
                    </View>
                </View>
            </View>
        </View>
    )
}

const styles = StyleSheet.create({
    imageView: {
        flex: 1,
        marginLeft: 24,
        marginRight: 24,
    },
    sampleText: {
        fontFamily: "Muli-SemiBold",
        fontSize: 12,
        color: "#999999",
        alignItems: "center",
        marginTop: 3,
    },
    rcTitle: {
        fontFamily: "Muli-Black",
        fontSize: 20,
        marginBottom: 17,
    },
    rcTypeText: {
        fontFamily: "Muli-Bold",
        fontSize: 14,
    },
});

export default RCBPreviewScreen;